@@ -31,7 +31,7 @@ fn test_once(data: &[u8]) {
     }
     eprintln!("{:?}", covenant.to_ops());
     eprintln!("{:?}", second.len());
-    covenant.check_raw(&[second.iter().map(|f| 0u8).collect::<Vec<_>>().into()]);
+    covenant.debug_run_without_transaction(&[second.iter().map(|_f| 0u8).collect::<Vec<_>>().into()]);
     if let Ok(ops) = covenant.to_ops() {
         assert_eq!(Covenant::from_ops(&ops).unwrap(), covenant);
     }
